pub struct MetadataAggregator { /* private fields */ }Expand description
Metadata aggregator based on configurable collectors.
Metadata collectors are used to either scrape or listen for changes in workload metadata, which converts those
changes into MetadataOperations that are applied to a MetadataStore. MetadataAggregator receives those
operations and applies them to all configured MetadataStores.
Implementations
Sourceimpl MetadataAggregator
impl MetadataAggregator
Sourcepub fn new(health: Health) -> (Self, Sender<MetadataOperation>)
pub fn new(health: Health) -> (Self, Sender<MetadataOperation>)
Creates a new MetadataAggregator, returning it along with the operations sender that should be cloned into
each collector worker.
Sourcepub fn add_store<S>(&mut self, store: S)where
S: MetadataStore + Send + 'static,
pub fn add_store<S>(&mut self, store: S)where
S: MetadataStore + Send + 'static,
Adds a metadata store to the aggregator.
This store will receive a copy of every metadata operation that’s emitted from the configured metadata collectors.